package WebGUI::i18n::Dutch::Asset_Post;
use utf8;
our $I18N = {
  523 => {
    'lastUpdated' => '1152727190',
    'message' => 'Notificatie'
  },
  875 => {
    'lastUpdated' => '1152727239',
    'message' => 'Er is een nieuw bericht geplaatst op een van uw abonnementen. '
  },
  'By' => {
    'lastUpdated' => '1152727256',
    'message' => 'Bij'
  },
  'Edited_on' => {
    'lastUpdated' => '1152727332',
    'message' => 'Bewerkt op'
  },
  'Skip notification' => {
    'lastUpdated' => '1269423208',
    'message' => 'Notificatie overslaan'
  },
  'add/edit post template title' => {
    'lastUpdated' => '1152727625',
    'message' => 'Plaats toevoegen/bewerken-sjabloon '
  },
  'approved' => {
    'lastUpdated' => '1152727722',
    'message' => 'Goedgekeurd'
  },
  'archive.form' => {
    'lastUpdated' => '1152727831',
    'message' => 'Een ja/nee-knop om de thread te archiveren als u dit antwoord verstuurt. Dit is alleen mogelijk voor moderators.'
  },
  'archived' => {
    'lastUpdated' => '1152727880',
    'message' => 'Gearchiveerd'
  },
  'assetName' => {
    'lastUpdated' => '1152727950',
    'message' => 'Bericht'
  },
  'assetSize' => {
    'lastUpdated' => '1152727969',
    'message' => 'De geformatteerde grootte van dit bericht. '
  },
  'attachment.form' => {
    'lastUpdated' => '1152728006',
    'message' => 'Code om toe te staan dat een bijlage aan dit bericht wordt toegevoegd. '
  },
  'attachment.icon' => {
    'lastUpdated' => '1152728086',
    'message' => 'Een icoon laat het bestandstype van deze bijlage zien.'
  },
  'attachment.name' => {
    'lastUpdated' => '1152728317',
    'message' => 'De naam van de eerste bijlage die bij het bericht gevonden wordt. '
  },
  'attachment.url' => {
    'lastUpdated' => '1152728368',
    'message' => 'De URL om de eerste bijlage bij het bericht te downloaden. '
  },
  'attachment_loop' => {
    'lastUpdated' => '1152729275',
    'message' => 'Een &#39;loop&#39; met alle bestands- en beeldbijlagen bij dit bericht. '
  },
  'avatar.url' => {
    'lastUpdated' => '1207830756',
    'message' => 'Een URL naar de avatar voor de eigenaar van dit bericht, als avatars mogelijk zijn in het hoofd-besturingssysteem en als de gebruiker een avatar heeft. '
  },
  'content' => {
    'lastUpdated' => '1152729472',
    'message' => 'De inhoud, &#39;body&#39;, van het bericht. '
  },
  'content.form' => {
    'lastUpdated' => '1152729553',
    'message' => 'Een veld om inhoud in te voeren of te bewerken, met alle macro&#39;s uitgeschakeld. Als het berichtenbord &#39;rich content&#39; toestaat, is het WYSIWIG HTML-ruimte. Anders is het ruimte voor platte tekst. '
  },
  'contentType' => {
    'lastUpdated' => '1152729597',
    'message' => 'Het soort inhoud in het bericht, te kiezen uit &#39;code&#39;, &#39;tekst&#39;, &#39;HTML&#39; en &#39;gemengd&#39;. '
  },
  'contentType.form' => {
    'lastUpdated' => '1152729672',
    'message' => 'Een veld van een formulier dat beschrijft hoe de inhoud van de post geformatteerd is: HTML, tekst, code of gemengd. Gemengd is standaard. '
  },
  'dateSubmitted' => {
    'lastUpdated' => '1152801532',
    'message' => 'De datum waarop het bericht is geplaatst, in epoch-formaat.'
  },
  'dateSubmitted.human' => {
    'lastUpdated' => '1152801557',
    'message' => 'De datum waarop het bericht is geplaatst, in leesbaar formaat.'
  },
  'dateUpdated' => {
    'lastUpdated' => '1152801591',
    'message' => 'De datum waarop het bericht voor het laatst is aangepast, in epoch-formaat. '
  },
  'dateUpdated.human' => {
    'lastUpdated' => '1152801625',
    'message' => 'De datum waarop het bericht voor het laatst is aangepast, in leesbaar formaat.'
  },
  'delete.url' => {
    'lastUpdated' => '1152801697',
    'message' => 'Een URL om dit bericht te verwijderen. '
  },
  'edit.url' => {
    'lastUpdated' => '1152801924',
    'message' => 'Een URL om dit bericht te bewerken. '
  },
  'extraHeadTags' => {
    'lastUpdated' => '1152802497',
    'message' => 'Extra tags die de gebruiker heeft aangevraagd om toe te voegen aan de HTML header. '
  },
  'field' => {
    'lastUpdated' => '1189458088',
    'message' => 'Het formulier element om dit metadata element mee in te geven.'
  },
  'filename' => {
    'lastUpdated' => '1152802529',
    'message' => 'De naam van de bijlage'
  },
  'form.cancel' => {
    'lastUpdated' => '1270629543',
    'message' => 'Een knop om de post te annuleren.'
  },
  'form.footer' => {
    'lastUpdated' => '1152802591',
    'message' => 'Code voor het einde van het reactieformulier'
  },
  'form.header' => {
    'lastUpdated' => '1152802617',
    'message' => 'Code die nodig is om het reactieformulier voor het bericht te starten'
  },
  'form.preview' => {
    'lastUpdated' => '1152802640',
    'message' => 'Een knop om het bericht alvast te bekijken '
  },
  'form.submit' => {
    'lastUpdated' => '1152802667',
    'message' => 'Een knop om het bericht te versturen '
  },
  'formatted.content' => {
    'lastUpdated' => '1166195928',
    'message' => 'De geformatteerde en gefilterde inhoud van een reactie als een bericht een reactie bevat. Deze variabele overschrijft alle andere variabelen met dezelfde naam in de lijst met sjabloon variabelen.'
  },
  'groupIdEdit' => {
    'lastUpdated' => '1152803130',
    'message' => 'Het ID van de groep met toestemming om dit bericht te bewerken '
  },
  'groupIdView' => {
    'lastUpdated' => '1152803152',
    'message' => 'Het ID van de groep met toestemming om dit bericht te bekijken '
  },
  'hasRated' => {
    'lastUpdated' => '1207831178',
    'message' => 'Een voorwaarde die waar is als de gebruiker het bericht al heeft beoordeeld '
  },
  'help url.raw' => {
    'lastUpdated' => '1207901128',
    'message' => 'Het URL van de post Asset zonder het id aan het einde. Dit is nuttig voor het uitvoeren van andere functies op de post zoals &quot;func=promote&quot; of &quot;func=demote&quot;.'
  },
  'icon' => {
    'lastUpdated' => '1152803401',
    'message' => 'Het icoon dat het bestandsformaat van de bijlage weergeeft. '
  },
  'image.thumbnail' => {
    'lastUpdated' => '1152803474',
    'message' => 'Een miniatuur van het plaatje in de bijlage van het bericht '
  },
  'image.url' => {
    'lastUpdated' => '1152803507',
    'message' => 'De URL van het eerste plaatje dat aan dit bericht is toegevoegd. '
  },
  'isEdit' => {
    'lastUpdated' => '1152803541',
    'message' => 'Een voorwaarde die waar is als de gebruiker een bestaand bericht aan het bewerken is.'
  },
  'isHidden' => {
    'lastUpdated' => '1152804120',
    'message' => 'Een voorwaarde die aangeeft of dit bericht moet worden verborgen in de navigatie. '
  },
  'isImage' => {
    'lastUpdated' => '1152804150',
    'message' => 'Een voorwaarde die aangeeft of de bijlage een plaatje is. '
  },
  'isNewPost' => {
    'lastUpdated' => '1152804329',
    'message' => 'Een voorwaarde die waar is als de gebruiker een nieuw bericht toevoegt, in tegenstelling tot het bewerken van een bestaand bericht. '
  },
  'isNewThread' => {
    'lastUpdated' => '1152805793',
    'message' => 'Een voorwaarde die waar is als de gebruiker bezig is een nieuwe thread toe te voegen. '
  },
  'isPackage' => {
    'lastUpdated' => '1152808489',
    'message' => 'Een voorwaarde die aangeeft of dit bericht een pakket is.'
  },
  'isPrototype' => {
    'lastUpdated' => '1152808524',
    'message' => 'Een voorwaarde die aangeeft of dit bericht een inhoud-prototype is '
  },
  'isReply' => {
    'lastUpdated' => '1152808563',
    'message' => 'Een voorwaarde die waar is als de gebruiker bezig is een bestaand bericht te beantwoorden'
  },
  'isSubscribedToCs' => {
    'lastUpdated' => '1278062166',
    'message' => 'Een functie die waar is wanneer de huidige gebruiker geabonneerd is op het CS met deze post.'
  },
  'isThread' => {
    'lastUpdated' => '1152808625',
    'message' => 'Een voorwaarde die waar is als de gebruiker bezig is het hoofdartikel van een thread te bewerken, in tegenstelling tot het beantwoorden binnen een thread. '
  },
  'karmaIsEnabled' => {
    'lastUpdated' => '1152808668',
    'message' => 'Een voorwaarde die waar is als karma mogelijk is gemaakt in de WebGUI-instellingen in de admin console voor deze site. '
  },
  'karmaScale.form' => {
    'lastUpdated' => '1152808882',
    'message' => 'Een onderdeel van een reactieformulier dat moderators in staat stelt de grootte van individuele threads te bepalen. Dit kan alleen bij threads.'
  },
  'keywords.form' => {
    'lastUpdated' => '1346179964',
    'message' => 'Een tekst-invoerveld om zoekwoorden in te voeren. '
  },
  'lock.form' => {
    'lastUpdated' => '1152808933',
    'message' => 'Een ja/nee-knop om de thread af te sluiten, zodat berichten niet kunnen worden toegevoegd noch bewerkt '
  },
  'menuTitle' => {
    'lastUpdated' => '1152808964',
    'message' => 'De menu-titel van het bericht, vaak gebruikt in navigatie. '
  },
  'meta_X_form' => {
    'lastUpdated' => '1189458136',
    'message' => 'Het formulier voor een specifiek metadata veld, gedefinieerd door zijn naam. X is de naam van het metadataveld, waarbij spaties in de naam worden omgezet in liggende streepjes. (underscores)'
  },
  'meta_X_value' => {
    'lastUpdated' => '1189458176',
    'message' => 'De waarde voor een specifiek metadata veld, bepaald door zijn naam. X is de naam van het metadataveld, waarbij spaties in de naam worden vervangen door liggende streepjes. (underscores)'
  },
  'meta_loop' => {
    'lastUpdated' => '1189458247',
    'message' => 'Een loop die de metadata labels en velden bevat voor dit bericht. Als metadata niet beschikbaar is voor de site als geheel, of wanneer metadata niet beschikbaar is voor dit Samenwerk Systeem (Collaboration System) of er is geen metadata gedefinieerd voor de site, dan is deze loop leeg.'
  },
  'name' => {
    'lastUpdated' => '1189458271',
    'message' => 'Het label voor dit metadata veld. Metadata labels zijn niet beschikbaar in de eigen taal van de gebruiker.'
  },
  'new file description' => {
    'lastUpdated' => '1208524843',
    'message' => '<p>Ga het pad of het bestand in, of gebruik de \'verkennen\'-knop om een bestand te vinden op uw lokale harde schijf, dat u zou willen uploaden. </p>'
  },
  'newWindow' => {
    'lastUpdated' => '1152809221',
    'message' => '<p>Een voorwaarde die aangeeft of dit bericht in een nieuw venster moet worden geopend. </p>'
  },
  'notification template body' => {
    'lastUpdated' => '1152809284',
    'message' => '<p>In aanvulling op de gewone berichtensjabloon-variabelen, heeft het notificatiesjabloon deze variabelen: </p>'
  },
  'notification template title' => {
    'lastUpdated' => '1152817900',
    'message' => 'Notificatie-sjabloon'
  },
  'notify url' => {
    'lastUpdated' => '1152818144',
    'message' => 'De URL van het bericht waarvoor de notificatie is verstuurd.'
  },
  'notify.subscription.message' => {
    'lastUpdated' => '1208524900',
    'message' => 'Het bericht in de eigen taal van de bezoeker waarin wordt aangegeven dat een nieuwe reactie geplaatst is bij een bericht waarop de gebruiker is geabonneerd.'
  },
  'ownerUserId' => {
    'lastUpdated' => '1152818192',
    'message' => 'Een nickname voor userId'
  },
  'pending' => {
    'lastUpdated' => '1152818224',
    'message' => 'In wachtrij'
  },
  'post asset variables title' => {
    'lastUpdated' => '1166195991',
    'message' => 'Reactie sjabloon variabelen'
  },
  'post received' => {
    'lastUpdated' => '1184244642',
    'message' => 'Uw bericht is ontvangen en in behandeling om te worden toegevoegd aan de site.'
  },
  'post template variables title' => {
    'lastUpdated' => '1152818474',
    'message' => 'Bericht-sjabloon-variabelen'
  },
  'preview.content' => {
    'lastUpdated' => '1152818561',
    'message' => 'De inhoud bij het voorvertonen van een bericht'
  },
  'preview.synopsis' => {
    'lastUpdated' => '1189366998',
    'message' => 'De samenvatting bij het voorvertonen van een bericht. Als geen samenvatting is ingegeven, dan zal het proberen een deel van de tekst weer te geven uit de beschrijving tot aan de ^-; markering. Als er geen markering wordt gevonden, dan wordt alles genomen tot aan de eerste nieuwe regel in de beschrijving.'
  },
  'preview.title' => {
    'lastUpdated' => '1152818813',
    'message' => 'De beschermde titel voor de voorvertoning van een bericht '
  },
  'preview.userDefinedN' => {
    'lastUpdated' => '1152822536',
    'message' => 'De inhoud van door de gebruiker vastgestelde velden voor het bericht zonder WebGUI-macro&#39;s is in behandeling. N varieert van 1 tot 5. '
  },
  'rate.url.thumbsDown' => {
    'lastUpdated' => '1152822596',
    'message' => 'Een negatieve beoordeling'
  },
  'rate.url.thumbsUp' => {
    'lastUpdated' => '1152822820',
    'message' => 'Een positieve beoordeling '
  },
  'rating' => {
    'lastUpdated' => '1152822893',
    'message' => 'Een ander woord voor waardering'
  },
  'rating.value' => {
    'lastUpdated' => '1152822933',
    'message' => 'De huidige beoordeling van dit bericht'
  },
  'relativeUrl' => {
    'lastUpdated' => '1166196086',
    'message' => 'Vult de URL relatief (/pad/naar/reactie) in in plaats van de volledige URL (http://host/pad/naar/reactie).'
  },
  'reply.content' => {
    'lastUpdated' => '1152823584',
    'message' => 'De inhoud van het&nbsp; bericht dat beantwoord wordt'
  },
  'reply.synopsis' => {
    'lastUpdated' => '1189367060',
    'message' => 'De samenvatting van het bericht dat beantwoord wordt. Als geen samenvatting is ingevoerd, dan zal getracht worden tekst uit de beschrijving te nemen tot aan de ^-; markering. Als geen markering wordt gevonden, dan wordt de beschrijving genomen tot aan de eerste nieuwe regel.'
  },
  'reply.title' => {
    'lastUpdated' => '1152823658',
    'message' => 'De titel van het bericht dat beantwoord wordt '
  },
  'reply.url' => {
    'lastUpdated' => '1152823734',
    'message' => 'De URL naar de beantwoording van dit bericht zonder het te citeren '
  },
  'reply.userDefinedN' => {
    'lastUpdated' => '1152830197',
    'message' => 'De inhoud van de door de gebruiker gedefinieerde velden van het bericht dat beantwoord wordt. N varieert van 1 tot 5. '
  },
  'reply.withQuote.url' => {
    'lastUpdated' => '1152830317',
    'message' => 'De URL om een antwoord met citaat op dit bericht te beginnen'
  },
  'skipNotification.form' => {
    'lastUpdated' => '1269433390',
    'message' => 'Een veld wat een gebruiker met de juiste rechten e-mail notificatie laat overslaan.'
  },
  'status' => {
    'lastUpdated' => '1152830427',
    'message' => 'De status van dit bericht: &#39;goedgekeurd&#39;, &#39;in wachtrij&#39;, &#39;gearchiveerd&#39; '
  },
  'sticky.form' => {
    'lastUpdated' => '1152830713',
    'message' => 'Een ja/nee-knop om de thread &#39;sticky&#39; te maken, zodat het bovenaan de forumlijst blijft staan. '
  },
  'storageId' => {
    'lastUpdated' => '1152831111',
    'message' => 'De asset ID van het geheugengebruik voor het bericht, waar de bijlagen worden gehouden'
  },
  'subscribe.form' => {
    'lastUpdated' => '1152831324',
    'message' => 'Een ja/nee-knop om de gebruiker zich te laten abonneren op de thread waar dit bericht bij hoort. '
  },
  'synopsis' => {
    'lastUpdated' => '1189367122',
    'message' => 'De samenvatting van het bericht. Als geen synopsis is ingevoerd, dan zal het tekst proberen te gebruiken uit de beschrijving van het bericht tot aan de ^-; markering. Als geen markering is gevonden, dan zal alles uit de beschrijving worden gebruikt tot aan de eerste nieuwe regel.'
  },
  'synopsis.form' => {
    'lastUpdated' => '1152834092',
    'message' => 'Een veld in een reactieformulier om de samenvatting in te voeren of te bewerken '
  },
  'threadId' => {
    'lastUpdated' => '1152836978',
    'message' => 'De ID van de thread die dit bericht bevat '
  },
  'thumbnail' => {
    'lastUpdated' => '1152837030',
    'message' => 'Een miniatuur van deze bijlage, indien van toepassing '
  },
  'title' => {
    'lastUpdated' => '1152837210',
    'message' => 'De titel van het bericht '
  },
  'title.form' => {
    'lastUpdated' => '1152837304',
    'message' => 'En eenregelig tekstveld in een reactieformulier om de titel in te voeren of te bewerken, zonder HTML en macro&#39;s uitgeschakeld. Gebruik deze OF title.form.textarea. '
  },
  'title.form.textarea' => {
    'lastUpdated' => '1152837363',
    'message' => 'Een tekstveld om de titel in te voeren of te bewerken, zonder HTML en macro&#39;s uitgeschakeld. Gebruik deze OF title.form. '
  },
  'title.short' => {
    'lastUpdated' => '1152837391',
    'message' => 'De titel van het bericht, beperkt tot 30 tekens '
  },
  'unsubscribeLinkText' => {
    'lastUpdated' => '1190025625',
    'message' => 'Het label in de eigen taal van de bezoeker, om aan te geven "geen reacties meer per email ontvangen".'
  },
  'unsubscribeUrl' => {
    'lastUpdated' => '1190025590',
    'message' => 'De URL om geen reacties meer per email te ontvangen. '
  },
  'url' => {
    'lastUpdated' => '1152837447',
    'message' => 'De URL om deze bijlage te downloaden'
  },
  'usePreview' => {
    'lastUpdated' => '1152837489',
    'message' => 'Een voorwaarde die aangeeft dat de berichten in deze thread worden voorvertoond voordat ze worden verstuurd '
  },
  'user.canEdit' => {
    'lastUpdated' => '1207831161',
    'message' => 'Een voorwaarde die waar is als de gebruiker bezig is een nieuw bericht te plaatsen, in tegenstelling tot het bewerken van een bestaand bericht, en er een thread bestaat, die het bericht bevat'
  },
  'user.isModerator' => {
    'lastUpdated' => '1152837626',
    'message' => 'Een voorwaarde die aangeeft of de huidige gebruiker moderator is. '
  },
  'user.isPoster' => {
    'lastUpdated' => '1152837685',
    'message' => 'Een voorwaarde die waar is als de huidige gebruiker de eigenaar van het bericht is.'
  },
  'user.isVisitor' => {
    'lastUpdated' => '1152837715',
    'message' => 'Een voorwaarde die aangeeft of de huidige gebruiker een bezoeker is.'
  },
  'userDefined1' => {
    'lastUpdated' => '1152838215',
    'message' => 'De waarde van de eerste door de gebruiker gedefinieerde variabele '
  },
  'userDefined2' => {
    'lastUpdated' => '1152838229',
    'message' => 'De waarde van de tweede door de gebruiker gedefinieerde variabele '
  },
  'userDefined3' => {
    'lastUpdated' => '1238673088',
    'message' => 'De waarde van de derde door de gebruiker gedefinieerde variabele '
  },
  'userDefined4' => {
    'lastUpdated' => '1152838293',
    'message' => 'De waarde van de vierde door de gebruiker gedefinieerde variabele '
  },
  'userDefined5' => {
    'lastUpdated' => '1152838306',
    'message' => 'De waarde van de vijfde door de gebruiker gedefinieerde variabele '
  },
  'userDefinedN.form' => {
    'lastUpdated' => '1152838396',
    'message' => 'Voor elke vijf door de gebruiker gedefinieerde velden een formulier-widget voor een regel tekst '
  },
  'userDefinedN.form.float' => {
    'lastUpdated' => '1152838509',
    'message' => 'Voor elke vijf door de gebruiker gedefinieerde velden een formulier-widget voor een float '
  },
  'userDefinedN.form.htmlarea' => {
    'lastUpdated' => '1152838554',
    'message' => 'Voor elke vijf door de gebruiker gedefinieerde velden een formulier-widget voor WYSIWIG HTML-ruimte '
  },
  'userDefinedN.form.textarea' => {
    'lastUpdated' => '1152838578',
    'message' => 'Voor elke vijf door de gebruiker gedefinieerde velden een formulier-widget voor tekstruimte '
  },
  'userDefinedN.form.yesNo' => {
    'lastUpdated' => '1152838593',
    'message' => 'Voor elke vijf door de gebruiker gedefinieerde velden een formulier-widget voor een ja/nee-veld'
  },
  'userId' => {
    'lastUpdated' => '1152838622',
    'message' => 'De gebruikers-ID van de eigenaar van het bericht '
  },
  'userProfile.url' => {
    'lastUpdated' => '1152837659',
    'message' => 'Een URL naar het profiel van de eigenaar van het bericht '
  },
  'username' => {
    'lastUpdated' => '1152837099',
    'message' => 'De naam van de gebruiker die dit bericht voor het laatst heeft bewerkt of die het heeft geplaatst '
  },
  'value' => {
    'lastUpdated' => '1189458289',
    'message' => 'De waarde van dit metadataveld voor dit bericht.'
  },
  'views' => {
    'lastUpdated' => '1207831259',
    'message' => 'Het aantal keren dat dit bericht is bekeken'
  },
  'visitorName.form' => {
    'lastUpdated' => '1152833853',
    'message' => 'Een reactieformulier waar de gebruiker zijn naam kan invullen, ook als hij bezoeker is. '
  }
}
;

1;
